@@ -161,6 +161,7 @@ enum {
   WINDOW_TYPE_DIALOG,
   WINDOW_TYPE_SPLASH,
   WINDOW_TYPE_DESKTOP,
+  WINDOW_TYPE_NORMAL,
   MB_COMMAND,
   MB_CLIENT_EXEC_MAP,
   MB_CLIENT_STARTUP_LIST,
@@ -453,6 +454,7 @@ typedef struct _kbdconfig_entry
   int                      action;
   KeySym                   key;
   int                      ModifierMask;
+  int                      index;
   char                    *sdata;
   int                      idata;
   struct _kbdconfig_entry *next_entry;
@@ -507,6 +509,7 @@ typedef struct _wm_config
   Bool         ping_aggressive;
   
   MBConfigKbd *kb;
+  char        *kbd_conf_file;
 
   char        *force_dialogs;
   char        *sm_client_id;
