@@ -188,6 +188,9 @@ wm_usage(char *progname)
    printf("\t-use_desktop_mode <decorated|plain>\n");
    printf("\t-use_super_modal  <yes|no>\n");
    printf("\t-force_dialogs    <comma seperated list of window titles>\n");
+#ifndef NO_KBD
+   printf("\t-kbdconfig        <path to option key shortcuts config file>\n");
+#endif
 #ifdef USE_SM
    printf("\t--sm-client-id    <session id>\n");
 #endif
@@ -423,7 +426,14 @@ wm_load_config (Wm   *w,
 	  w->config->force_dialogs = argv[i];
 	  continue;
 	}
-
+#ifndef NO_KBD
+      if (!strcmp ("-kbdconfig", argv[i])) 
+	{
+	  if (++i>=*argc) wm_usage (argv[0]);
+	  w->config->kbd_conf_file = argv[i];
+	  continue;
+	}
+#endif
 #ifdef USE_SM
    if (!strcmp ("--sm-client-id", argv[i]))
      {
@@ -455,7 +465,7 @@ wm_load_config (Wm   *w,
    char              *type;
    XrmValue          value;
    
-   static int opTableEntries = 11;
+   static int opTableEntries = 12;
    static XrmOptionDescRec opTable[] = {
       {"-theme",       ".theme",           XrmoptionSepArg, (XPointer) NULL},
       {"-use_titlebar",".titlebar",        XrmoptionSepArg, (XPointer) NULL},
@@ -468,6 +478,7 @@ wm_load_config (Wm   *w,
       {"-force_dialogs",  ".forcedialogs", XrmoptionSepArg, (XPointer) NULL},
       {"--sm-client-id",  ".session",      XrmoptionSepArg, (XPointer) NULL},
       {"-use_super_modal", ".supermodal",  XrmoptionSepArg, (XPointer) NULL},
+      {"-kbdconfig", ".kbdconfig",         XrmoptionSepArg, (XPointer) NULL},
    };
 
    XrmInitialize();
@@ -512,7 +523,6 @@ wm_load_config (Wm   *w,
      {
        srDB = XrmGetStringDatabase(XResourceManagerString(w->dpy));
        if (srDB) XrmCombineDatabase(srDB, &rDB, False);
-
      }
 
    if (XrmGetResource(rDB, "matchbox.theme",
@@ -541,6 +551,18 @@ wm_load_config (Wm   *w,
      w->config->force_dialogs[value.size] = '\0';
      dbg("%s() got force dialogs :%s ", __func__, w->config->force_dialogs);
    }
+
+#ifndef NO_KBD
+   if (XrmGetResource(rDB, "matchbox.kbdconfig",
+		      "Matchbox.Keybdconfig",
+		      &type, &value) == True)
+   {
+     w->config->kbd_conf_file = (char *)malloc(sizeof(char)*(value.size+1));
+     strncpy(w->config->kbd_conf_file, value.addr, (int) value.size);
+     w->config->kbd_conf_file[value.size] = '\0';
+     dbg("%s() got kbdconfig :%s ", __func__, w->config->kbd_conf_file);
+   }
+#endif
    
    if (XrmGetResource(rDB, "matchbox.titlebar", "Matchbox.Titlebar",
 		      &type, &value) == True)
@@ -1056,7 +1078,7 @@ wm_handle_keypress(Wm *w, XKeyEvent *e)
    
    while (entry != NULL)
      {
-       if (XKeycodeToKeysym(w->dpy,e->keycode,0) == entry->key
+       if (XKeycodeToKeysym(w->dpy, e->keycode, entry->index) == entry->key
 	   && e->state == entry->ModifierMask )
 	{
 	  switch (entry->action) 
@@ -1440,7 +1462,6 @@ wm_handle_configure_request (Wm *w, XConfigureRequestEvent *e )
         * - eg toolbar/panel/input windows may dissapear and make
         *      more space available. 
         */
-
        if (e->width && (value_mask & CWWidth) 
 	   && e->width != c->width && e->width != c->init_width)
 	 c->init_width = e->width;
@@ -1491,17 +1512,6 @@ wm_handle_configure_request (Wm *w, XConfigureRequestEvent *e )
 
 	   dialog_constrain_geometry(c, &req_x, &req_y, &req_w, &req_h);
 
-#ifdef USE_ALT_INPUT_WIN
-	 /* Alternate Input windows use the dialog type to 
-	  * fit in with stacking etc but they cant change width,x
-	  */
-	 if (c->flags & (CLIENT_TB_ALT_TRANS_FOR_DIALOG
-	                   |CLIENT_TB_ALT_TRANS_FOR_APP))
-	   {
-	     req_w = c->init_width = c->width;
-	     req_x = c->x;
-	   }
-#endif
 	   if (c->width == req_w && c->height == req_h)
 	     want_fake_configure = True; 
 
@@ -1509,11 +1519,16 @@ wm_handle_configure_request (Wm *w, XConfigureRequestEvent *e )
 	   if (c->width != req_w)
 	     client_buttons_delete_all(c);
 
+	   /* TODO: fix composite for this */
+	   // comp_engine_client_hide(c->wm, c);
+	   
 	   xwc.width  = c->width  = req_w;
 	   xwc.height = c->height = req_h;
 	   xwc.x      = c->x      = req_x;
 	   xwc.y      = c->y      = req_y; 
 
+	   dbg("GRAVITY: x:%i y:%i\n", c->x, c->y);
+
 	   /* ICCCM says if window only moved - not size change,
             * then we send a fake one too.
 	    */
@@ -1753,6 +1768,8 @@ wm_handle_property_change(Wm *w, XPropertyEvent *e)
       Window  trans_win = 0;
       int     success = 0;
 
+      dbg("%s() got a tranciency change\n", __func__);
+
       misc_trap_xerrors(); 
 
       success = XGetTransientForHint(w->dpy, c->window, &trans_win);
@@ -1762,6 +1779,8 @@ wm_handle_property_change(Wm *w, XPropertyEvent *e)
 	  {
 	    Client *p = new_trans_client;
 
+	    dbg("%s() <%s> changing trans", __func__, new_trans_client->name);
+
 	    /* Dont let clients be change transiency to themselves
              * either directly or recursively.
 	    */
@@ -1957,6 +1976,12 @@ wm_make_new_client(Wm *w, Window win)
 		   if (c == NULL) goto end;
 		   c->flags |= CLIENT_HAS_URGENCY_FLAG;
 		 }
+	       else if (value[0] == w->atoms[WINDOW_TYPE_NORMAL])
+		 {
+		   c = main_client_new(w, win);
+		   if (c == NULL) goto end;
+		   c->flags ^= mwm_flags;
+		 }
 	     } 
 	 }
        
@@ -2418,7 +2443,7 @@ wm_activate_client(Client *c)
 {
   Wm     *w;
   Client *client_to_focus = c;
-  Bool    set_desktop_show_hint = False;
+  Bool    set_desktop_show_hint = False, set_current_app_active_hint = False;
 #ifndef NO_PING
   Client *prev_app_client = NULL;
 #endif
@@ -2445,7 +2470,6 @@ wm_activate_client(Client *c)
       __func__, (w->flags & DESKTOP_RAISED_FLAG));
 
 
-
   if (c->type == MBCLIENT_TYPE_APP || c->type == MBCLIENT_TYPE_DESKTOP) 
     {
       /* As matchbox works around 'main' windows ( apps/main and desktop wins).
@@ -2496,6 +2520,9 @@ wm_activate_client(Client *c)
 
       stack_move_type_above_client(w, MBCLIENT_TYPE_TOOLBAR, c);
 
+      dbg("%s() c is trans for <%s>\n", __func__,
+	  c->trans ? c->trans->name : "nothing");
+
       wm_stack_dialogs_for_transient(w, c);
 
       /* Deal with desktop flag etc */
@@ -2529,8 +2556,8 @@ wm_activate_client(Client *c)
 	}
 
       /* Set active main client, set focus handles active win hint */
-      ewmh_set_current_app_window(w);
-
+      set_current_app_active_hint = True;
+     
 #ifdef USE_ALT_INPUT_WIN
       /* If switching from/to fullscreen, then there could be an 
        * input window transient for a transient for root dialog and
@@ -2628,9 +2655,11 @@ wm_activate_client(Client *c)
       XMapWindow(w->dpy, c->frame);
     }
 
-
   client_set_focus(client_to_focus); /* set focus if needed and ewmh active */
 
+  if (set_current_app_active_hint)
+    ewmh_set_current_app_window(w);
+
   comp_engine_client_show(w, c);
 
 #ifndef NO_PING
